.. _base_models:

BaseModels
==========


.. autoclass:: nuaal.Models.BaseModels.BaseModel
    :members:
    :private-members:
    :undoc-members:
    :show-inheritance:

.. autoclass:: nuaal.Models.BaseModels.DeviceBaseModel
    :members:
    :private-members:
    :undoc-members:
    :show-inheritance: